import 'package:healthrian_ble_interface/healthrian_ble_interface.dart';
import 'package:healthrian_ble_support_for_cardioclick/'
    'healthrian_ble_support_for_cardioclick.dart';

class BLEManager {
  factory BLEManager() {
    return _instance;
  }

  BLEManager._internal() {}

  static final BLEManager _instance = BLEManager._internal();

  Versions versions = Versions.v1;

  ModuleBle get ble => versions == Versions.v1 ? bleV1 : bleV2;

  ModuleEcg get ecg => versions == Versions.v1 ? ecgV1 : ecgV2;

  ModuleBle bleV1 = ModuleBle(
    uuid: UUID(),
  )..scanFilter = ModuleBleBuiltin.scanFilterCardioClick;

  late ModuleEcg ecgV1 = ModuleEcg(ble: bleV1);

  ModuleBle bleV2 = ModuleBle(
    uuid: UUID(
      characteristicStringMap: {
        Characteristics.LEAD_STATE_ECG: '00002C00-0000-1000-8000-00805F9B34FB',
        Characteristics.MEASUREMENT_ECG: '00002C08-0000-1000-8000-00805F9B34FB',
        Characteristics.TAP_BUTTON: '00002C0F-0000-1000-8000-00805F9B34FB',
        Characteristics.CONTROL_POINT: '00002CF0-0000-1000-8000-00805F9B34FB',
        Characteristics.CONTROL_POINT_RESPONSE:
            '00002CF1-0000-1000-8000-00805F9B34FB',
        Characteristics.BATTERY_LEVEL: '00002A19-0000-1000-8000-00805F9B34FB',
        Characteristics.PRODUCT_MANUFACTURER:
            '00002A29-0000-1000-8000-00805F9B34FB',
        Characteristics.FIRMWARE_VERSION:
            '00002A26-0000-1000-8000-00805F9B34FB',
        Characteristics.SERIAL_NUMBER: '00002A25-0000-1000-8000-00805F9B34FB',
      },
    ),
  )..scanFilter = ModuleBleBuiltin.scanFilterCardioClick;

  late ModuleEcg ecgV2 = ModuleEcg(
    ble: bleV2,
    commands: Commands(
      ecg: CommandsEcg(
        startSave: [0x81],
        start: [0x11],
        stop: [0x82],
      ),
      ble: CommandsBle(
        firmware: [0xFA],
        setDate: [0x80],
      ),
    ),
    udfLeadStream: Builtin.udfLeadStreamCardioClick,
    udfConvert: Builtin.udfConvertCardioClick,
    udfLeadCompute: Builtin.udfLeadComputeCardioClick,
  )
    ..samplingRate = 500
    ..channelCount = 12
    ..sampleCount = 10
    ..filterCount = 8
    ..maxBuffer = 40 * 500
    ..lengthBuffer = 30 * 500
    ..displayBuffer = 5 * 500
    ..refreshBuffer = 500 ~/ 2;
}
